""" wenxin global variables """
import os

# http request
TIMEOUT_SECS = 600
MAX_CONNECTION_RETRIES = 2
REQUEST_SLEEP_TIME = 20
ACCESS_TOKEN_URL = "https://wenxin.baidu.com/moduleApi/portal/api/oauth/token"
API_REQUEST_URLS = ["https://wenxin.baidu.com/moduleApi/portal/api/rest/1.0/ernie/1.0/tuning",
                    "https://wenxin.baidu.com/moduleApi/portal/api/rest/1.0/ernie/3.0.28/zeus"]

VILG_CREATE_URL = "https://wenxin.baidu.com/moduleApi/portal/api/rest/1.0/ernievilg/v1/txt2img"
VILG_RETRIEVE_URL = "https://wenxin.baidu.com/moduleApi/portal/api/rest/1.0/ernievilg/v1/getImg"

ak = os.environ.get("WENXINAPI_AK", None)
sk = os.environ.get("WENXINAPI_SK", None)
access_token = os.environ.get("WENXINAPI_ACCESS_TOKEN", None)
debug = False
proxy = None



""" wenxin api python bindings. """

import os
from typing import Optional
from wenxin_api.base_object import BaseObject
from wenxin_api.api import Task, Dataset, Train, Model
from wenxin_api.error import WenxinError, APIError, InvalidRequestError
from wenxin_api.requestor import WenxinAPIResponse
from wenxin_api.variable import ak, sk, access_token, proxy, debug
from wenxin_api import const, log

__all__ = [
    "Task"
    "Dataset",
    "Train",
    "Model",
    "BaseObject",
    "APIError",
    "WenxinError",
    "InvalidRequestError",
    "ak",
    "sk",
    "access_token",
    "api_type",
    "log",
    "const"
]